#ifndef _MACRO_H
#define _MACRO_H 1

/* ---------------------------------------------------------------------- */

extern void macroconfig_load(void);

extern void macroconfig(gint n);
extern void macroconfig_clear(void);
extern void macroconfig_close(gboolean save);
extern void macroconfig_delete(void);

extern void send_macro(gint n);

/* ---------------------------------------------------------------------- */

#define MACRODEF1NAME	""
#define	MACRODEF1TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF2NAME	""
#define MACRODEF2TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF3NAME	""
#define MACRODEF3TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF4NAME	""
#define MACRODEF4TEXT	""

/* ---------------------------------------------------------------------- */
#define MACRODEF5NAME	""
#define MACRODEF5TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF6NAME	""
#define MACRODEF6TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF7NAME	""
#define MACRODEF7TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF8NAME	""
#define MACRODEF8TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF9NAME	""
#define MACRODEF9TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF10NAME	""
#define MACRODEF10TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF11NAME	""
#define MACRODEF11TEXT	""

/* ---------------------------------------------------------------------- */

#define MACRODEF12NAME	""
#define MACRODEF12TEXT	""

/* ---------------------------------------------------------------------- */

#endif
